;
; ============================================================
;
;   9S12XEQU.asm	MC9S12XDP512 Equates
;                                 
;   Version:	  1.0   Created 09/10/04
;   Author:		  Spencer Ruggles , Axiom Mfg.
;   Compiler:	  AS12
;       
;   Platform:	  DEMO9S12XDP512 
;   Purpose:	  MCU register equates
; ============================================================
;
; This file lists the commonly used register equates for the MC9S12XDP512
; MCU.  This file does not comprise the complete register map.  Missing
; registers will be added as needed.
;
;
 
;********** Port Integration Module (PIM) 1 0f 5 **********
                                        
PORTA:     equ $0000   ; Port A Data 
PORTB:     equ $0001   ; Port B Data 
DDRA:      equ $0002   ; Port A Data Direction
DDRB:      equ $0003   ; Port B Data Direction
PORTC:     equ $0004   ; Port C Data
PORTD:     equ $0005   ; Port D Data
DDRC:      equ $0006   ; Port C Data Direction
DDRD:      equ $0007   ; Port D Data Direction
PORTE:     equ $0008   ; Port E Data
DDRE:      equ $0009   ; Port E Data Direction
                                        
;********** Module Mapping control (S12XMMC) 1 0f 4 **********
                                        
MMCCTL0:   equ $000A   ; MMC Control 0
MODE:      equ $000B   ; MMC Mode  
                                        
;********** Port Integration Module (PIM) 2 of 5 **********
                                        
PUCR:      equ $000C   ; Pull Up Control 
RDRIV:     equ $000D   ; Reduced Drive Control
                                        
;********** External Bus Interface (S12XEBI) **********
                                        
EBICTL:    equ $000E   ; EBI control
EBISIZ:    equ $000F   ; EBI Size
                                        
;********** Module Mapping control (S12XMMC) 2 0f 4 **********
                                        
GPAGE:     equ $0010    ; Global Page Index
DIRECT:    equ $0011    ; Direct Page Register 
MMCCTL1:   equ $0013    ; MMC control 1
RPAGE:     equ $0016    ; RAM Page Index
EPAGE:     equ $0017    ; EEPROM Page Index
                                        
;********** Miscellaneous Peripheral **********
                                        
PARTIDH:   equ $001A    ; Part ID High Byte
PARTIDL:   equ $001B    ; Part ID Low Byte
                                        
;********** Port Integration Module (PIM) 3 of 5 **********
                                        
ECLKCTL:   equ $001C    ; E Clock Control
IRQCR:     equ $001E    ; IRQ Control
                                        
;********** Debug Module (S12XDBG) **********
                                        
DBGC1:     equ $0020    ; Control 1
DBGSR:     equ $0021    ; Status Register 
DBGTCR:    equ $0022    ; Trace Control
DBGC2:     equ $0023    ; Control 2
BDGTBH:    equ $0024    ; Trace Buffer Hi
DBGTBL:    equ $0025    ; Trace Buffer Lo
DBGCNT:    equ $0026    ; Count
DBGSCR1:   equ $0027    ; State Control (visible when COMRV in DBGC1=00)
;DBGSCR1:   equ $0027    ; State Control (visible when COMRV in DBGC1=01)
DBGSCR3:   equ $0027    ; State Control (visible when COMRV in DBGC1=10,11)
DBGXCTL:   equ $0028    ; Comparator Control (A/C or B/D)
DBGXAH:    equ $0029    ; Comparator Address Hi
DBGXAM:    equ $002A    ; Comparator Address Mid
DBGXAL:    equ $002B    ; Comparator Address Lo
DBGXDH:    equ $002C    ; Comparator Data Hi
DBGXDL:    equ $002D    ; Comparator Data Lo
DBGXDHM:   equ $002E    ; Comparator Data Hi Mask
DBGXDLM:   equ $002F    ; Comparator Data Lo Mask
                                        
;********** Module Mapping control (S12XMMC) 3 0f 4 **********
                                        
PPAGE:     equ $0030    ; Program Page Index
                                        
;********** Port Integration Module (PIM) 3 of 5 **********
                                        
PORTK:     equ $0032     ; Port K Data
DDRK:      equ $0033     ; Port K Data Direction
                                        
;********** Clock and Rest Generator (CRG) **********
                                        
SYNR:      equ $0034     ; Synthesizer
REFDV:     equ $0035     ; Reference Divisor
CRGFLG:    equ $0037     ; Flags
CRGINT:    equ $0038     ; Interrupt Enable
CLKSEL:    equ $0039     ; Clock Select
PLLCTL:    equ $003A     ; PLL Control 
RTICTL:    equ $003B     ; RTI Control
COPCTL:    equ $003C     ; COP control
ARMCOP:    equ $003F     ; Arm COP Count

;
ATD1DIEN0:  equ $008C    ; Digital enable
ATD1DIEN:   equ $008D    ; Digital enable
PORTAD0:    equ $008E    ; 
PORTAD1:    equ $008F    ; Digital Output
                                        
;********** Asynchronous Serial Interface (SCI) **********
                                        
SCI2BDH:   equ $00B8     ; SCI2 Baud Rate High (visible if AMAP in SCI2SR2=0)
SCI2BDL:   equ $00B9     ; SCI2 Baud Rate Low (visible if AMAP in SCI2SR2=0)
SCI2CR1:   equ $00BA     ; SCI2 Control 1 (visible if AMAP in SCI2SR2=0)
SCI2ASR1:  equ $00B8     ; SCI2 Status 1 Alt (visible if AMAP in SCI2SR2=1)
SCI2ACR1:  equ $00B9     ; SCI2 Conrol 1 Alt (visible if AMAP in SCI2SR2=1)
SCI2ACR2:  equ $00BA     ; SCI2 Control 2 Alt (visible if AMAP in SCI2SR2=1)
SCI2CR2:   equ $00BB     ; SCI2 Control 2
SCI2SR1:   equ $00BC     ; SCI2 Status 1
SCI2SR2:   equ $00BD     ; SCI2 Status 2
SCI2DRH:   equ $00BE     ; SCI2 High Data 
SCI2DRL:   equ $00BF     ; SCI2 Low Data 

SCI3BDH:   equ $00C0     ; SCI3 High Data (visible if AMAP in SCI3SR2=0)
SCI3BDL:   equ $00C1     ; SCI3 Low Data (visible if AMAP in SCI3SR2=0) 
SCI3CR1:   equ $00C2     ; SCI3 Control 1 (visible if AMAP in SCI3SR2=0)
SCI3ASR1:  equ $00C0     ; SCI3 Status 1 Alt (visible if AMAP in SCI3SR2=1)
SCI3ACR1:  equ $00C1     ; SCI3 Conrol 1 Alt (visible if AMAP in SCI3SR2=1)
SCI3ACR2:  equ $00C2     ; SCI3 Control 2 Alt (visible if AMAP in SCI3SR2=1)
SCI3CR2:   equ $00C3     ; SCI3 Control 2
SCI3SR1:   equ $00C4     ; SCI3 Status 1
SCI3SR2:   equ $00C5     ; SCI3 Status 2
SCI3DRH:   equ $00C6     ; SCI3 High Data 
SCI3DRL:   equ $00C7     ; SCI3 Low Data 

SCI0BDH:   equ $00C8     ; SCI0 High Data (visible if AMAP in SCI0SR2=0)
SCI0BDL:   equ $00C9     ; SCI0 Low Data (visible if AMAP in SCI0SR2=0) 
SCI0CR1:   equ $00CA     ; SCI0 Control 1 (visible if AMAP in SCI0SR2=0)
SCI0ASR1:  equ $00C8     ; SCI0 Status 1 Alt (visible if AMAP in SCI0SR2=1)
SCI0ACR1:  equ $00C9     ; SCI0 Conrol 1 Alt (visible if AMAP in SCI0SR2=1)
SCI0ACR2:  equ $00CA     ; SCI0 Control 2 Alt (visible if AMAP in SCI0SR2=1)
SCI0CR2:   equ $00CB     ; SCI0 Control 2
SCI0SR1:   equ $00CC     ; SCI0 Status 1
SCI0SR2:   equ $00CD     ; SCI0 Status 2
SCI0DRH:   equ $00CE     ; SCI0 High Data 
SCI0DRL:   equ $00CF     ; SCI0 Low Data 

SCI1BDH:   equ $00D0     ; SCI1 High Data (visible if AMAP in SCI1SR2=0)
SCI1BDL:   equ $00D1     ; SCI1 Low Data (visible if AMAP in SCI1SR2=0) 
SCI1CR1:   equ $00D2     ; SCI1 Control 1 (visible if AMAP in SCI1SR2=0)
SCI1ASR1:  equ $00D0     ; SCI1 Status 1 Alt (visible if AMAP in SCI1SR2=1)
SCI1ACR1:  equ $00D1     ; SCI1 Conrol 1 Alt (visible if AMAP in SCI1SR2=1)
SCI1ACR2:  equ $00D2     ; SCI1 Control 2 Alt (visible if AMAP in SCI1SR2=1)
SCI1CR2:   equ $00D3     ; SCI1 Control 2
SCI1SR1:   equ $00D4     ; SCI1 Status 1
SCI1SR2:   equ $00D5     ; SCI1 Status 2
SCI1DRH:   equ $00D6     ; SCI1 High Data 
SCI1DRL:   equ $00D7     ; SCI1 Low Data 
                                        
;********** Asynchronous Serial Interface (SCI) **********
                                        
SPI0CR1:   equ $00D8     ; SPI0 Control 1
SPI0CR2:   equ $00D9     ; SPI0 Control 2
SPI0BR:    equ $00DA     ; SPI0 Baud Rate
SPI0SR:    equ $00DB     ; SPI0 Status
SPI0DR:    equ $00DD     ; SPI0 Data

SPI1CR1:   equ $00F0     ; SPI1 Control 1
SPI1CR2:   equ $00F1     ; SPI1 Control 2
SPI1BR:    equ $00F2     ; SPI1 Baud Rate
SPI1SR:    equ $00F3     ; SPI1 Status
SPI1DR:    equ $00F5     ; SPI1 Data

SPI2CR1:   equ $00F8     ; SPI2 Control 1
SPI2CR2:   equ $00F9     ; SPI2 Control 2
SPI2BR:    equ $00FA     ; SPI2 Baud Rate
SPI2SR:    equ $00FB     ; SPI2 Status
SPI2DR:    equ $00FD     ; SPI2 Data
                                        
;********** Flash Control Register (FTX512K4) **********
                                        
FCLKDIV:   equ $0100     ; Flash Clock Divisor
FSEC:      equ $0101     ; Flash Security 
FTSTMOD:   equ $0102     ; Flsh Test Mode
FCNFG:     equ $0103     ; Flash Configuraton
FPROT:     equ $0104     ; Flash Protection
FSTAT:     equ $0105     ; Flash Status
FCMD:      equ $0106     ; Flash Command
FCTL:      equ $0107     ; Flash Control
FADDRHI:   equ $0108     ; Flash Address High
FADDRLO:   equ $0109     ; Flash Address Lo
FDATAHI:   equ $010A     ; Flash Data Hi
FDATALO:   equ $010B     ; Flash Data Lo
                                        
;********** EEPROM Control Register (EETX4K) **********
                                        
ECLKDIV:   equ $0110     ; EEPROM Clock Divisor
ECNFG:     equ $0113     ; EEPROM Configuration
EPROT:     equ $0114     ; EEPROM Protection
ESTAT:     equ $0105     ; EEPROM Status
ECMD:      equ $0116     ; EEPROM Command 
EADDRHI:   equ $0118     ; EEPROM Address Hi
EADDRLO:   equ $0119     ; EEPROM Address Lo
EDATAHI:   equ $011A     ; EEPROM Data Hi
EDATALO:   equ $011B     ; EEPROM Data Lo
                                        
;********** Interrupt Module (S12XINT) MAP **********

IVBR:         equ $0121     ; Int Vector Base Addr
INT_XGPRIO:   equ $0126     ; XGATE Int Prio Config
INT_CFADDR:   equ $0127     ; XGATE Int Req Config Addr
INT_CFDATA0:  equ $0128     ; XGATE Int Req Config Data 0
INT_CFDATA1:  equ $0129     ; XGATE Int Req Config Data 1
INT_CFDATA2:  equ $012A     ; XGATE Int Req Config Data 2
INT_CFDATA3:  equ $012B     ; XGATE Int Req Config Data 3
INT_CFDATA4:  equ $012C     ; XGATE Int Req Config Data 4
INT_CFDATA5:  equ $012D     ; XGATE Int Req Config Data 5
INT_CFDATA6:  equ $012E     ; XGATE Int Req Config Data 6
INT_CFDATA7:  equ $012F     ; XGATE Int Req Config Data 7

;********** Asynchronous Serial Interface (SCI) **********
                                        
SCI4BDH:   equ $0130     ; SCI4 High Data (visible if AMAP in SCI4SR2=0)
SCI4BDL:   equ $0131     ; SCI4 Low Data (visible if AMAP in SCI4SR2=0) 
SCI4CR1:   equ $0132     ; SCI4 Control 1 (visible if AMAP in SCI4SR2=0)
SCI4ASR1:  equ $0130     ; SCI4 Status 1 Alt (visible if AMAP in SCI4SR2=1)
SCI4ACR1:  equ $0131     ; SCI4 Conrol 1 Alt (visible if AMAP in SCI4SR2=1)
SCI4ACR2:  equ $0132     ; SCI4 Control 2 Alt (visible if AMAP in SCI4SR2=1)
SCI4CR2:   equ $0133     ; SCI4 Control 2
SCI4SR1:   equ $0134     ; SCI4 Status 1
SCI4SR2:   equ $0135     ; SCI4 Status 2
SCI4DRH:   equ $0136     ; SCI4 High Data 
SCI4DRL:   equ $0137     ; SCI4 Low Data 

SCI5BDH:   equ $0138     ; SCI5 High Data (visible if AMAP in SCI5SR2=0)
SCI5BDL:   equ $0139     ; SCI5 Low Data (visible if AMAP in SCI5SR2=0) 
SCI5CR1:   equ $013A     ; SCI5 Control 1 (visible if AMAP in SCI5SR2=0)
SCI5ASR1:  equ $0138     ; SCI5 Status 1 Alt (visible if AMAP in SCI5SR2=1)
SCI5ACR1:  equ $0139     ; SCI5 Conrol 1 Alt (visible if AMAP in SCI5SR2=1)
SCI5ACR2:  equ $013A     ; SCI5 Control 2 Alt (visible if AMAP in SCI5SR2=1)
SCI5CR2:   equ $013B     ; SCI5 Control 2
SCI5SR1:   equ $013C     ; SCI5 Status 1
SCI5SR2:   equ $013D     ; SCI5 Status 2
SCI5DRH:   equ $013E     ; SCI5 High Data 
SCI5DRL:   equ $013F     ; SCI5 Low Data 
                                        
;********** Port Integration Module PIM_9DX (PIM) **********
                                        
PTT:       equ $0240     ; Port T Data
PTIT:      equ $0241     ; Port T Input
DDRT:      equ $0242     ; Port T Data Direction
RDRT:      equ $0243     ; Port T Reduced Drive
PERT:      equ $0244     ; Port T Pull Enable
PPST:      equ $0245     ; Port T Polarity Select

PTS:       equ $0248     ; Port S Data
PTIS:      equ $0249     ; Port S Input
DDRS:      equ $024A     ; Port S Data Direction
RDRS:      equ $024B     ; Port S Reduced Drive
PERS:      equ $024C     ; Port S Pull Enable
PPSS:      equ $024D     ; Port S Polarity Select
WOMS:      equ $024E     ; Port S Wired-OR Mode

PTM:       equ $0250     ; Port M Data
PTIM:      equ $0251     ; Port M Input
DDRM:      equ $0252     ; Port M Data Direction
RDRM:      equ $0253     ; Port M Reduced Drive
PERM:      equ $0254     ; Port M Pull Enable
PPSM:      equ $0255     ; Port M Polarity Select
WOMM:      equ $0256     ; Port M Wired-OR Mode
MODRR:     equ $0257     ; Module Routing Register

PTP:       equ $0258     ; Port P Data
PTIP:      equ $0259     ; Port P Input
DDRP:      equ $025A     ; Port P Data Direction
RDRP:      equ $025B     ; Port P Reduced Drive
PERP:      equ $025C     ; Port P Pull Enable
PPSP:      equ $025D     ; Port P Polarity Select
PIEP:      equ $025E     ; Port P Interrupt Enable
PIFP:      equ $025F     ; Port P Interrupt Flag

PTH:       equ $0260     ; Port H Data
PTIH:      equ $0261     ; Port H Input
DDRH:      equ $0262     ; Port H Data Direction
RDRH:      equ $0263     ; Port H Reduced Drive
PERH:      equ $0264     ; Port H Pull Enable
PPSH:      equ $0265     ; Port H Polarity Select
PIEH:      equ $0266     ; Port H Interrupt Enable
PIFH:      equ $0267     ; Port H Interrupt Flag

PTJ:       equ $0268     ; Port J Data
PTIJ:      equ $0269     ; Port J InJut
DDRJ:      equ $026A     ; Port J Data Direction
RDRJ:      equ $026B     ; Port J Reduced Drive
PERJ:      equ $026C     ; Port J Pull Enable
PPSJ:      equ $026D     ; Port J Polarity Select
PIEJ:      equ $026E     ; Port J Interrupt Enable
PIFJ:      equ $026F     ; Port J Interrupt Flag

PT1AD0:    equ $0271     ; Port AD0 Data
DDR1AD0:   equ $0273     ; Port AD0 Data Direction
RDR1AD0:   equ $0275     ; Port AD0 Reduced Drive
PER1AD0:   equ $0277     ; Port AD0 Pull Enable

;
PT0AD1:    equ $0278     ; Port AD1 Data 0
PT1AD1:    equ $0279     ; Port AD1 Data 1
DDR0AD1:   equ $027A     ; Port AD1 Data Direction 0
DDR1AD1:   equ $027B     ; Port AD1 Data Direction 1
RDR0AD1:   equ $027C     ; Port AD1 Reduced Drive 0
RDR1AD1:   equ $027D     ; Port AD1 Reduced Drive 1
PER0AD1:   equ $027E     ; Port AD1 Pull Enable 0
PER1AD1:   equ $027F     ; Port AD1 Pull Enable 1

;
ATD0CTL0:  equ $02C0     ; A/D Control
ATD0CTL1:  equ $02C1     ; A/D Control
ATD0CTL2:  equ $02C2     ; A/D Control
ATD0CTL3:  equ $02C3     ; A/D Control
ATD0CTL4:  equ $02C4     ; A/D Control
ATD0CTL5:  equ $02C5     ; A/D Control


;
ATD0DIEN:  equ $02CD     ; Digital Enable

;PORTAD0:   equ $02CF     ; 
ATD0DR0H:  equ $02D0     ;
ATD0DR0L:  equ $02D1     ;
ATD0DR1H:  equ $02D2     ;
ATD0DR1L:  equ $02D3     ;
ATD0DR2H:  equ $02D4     ;
ATD0DR2L:  equ $02D5     ;
ATD0DR3H:  equ $02D6     ;
ATD0DR3L:  equ $02D7     ;
ATD0DR4H:  equ $02D8     ;
ATD0DR4L:  equ $02D9     ;
ATD0DR5H:  equ $02DA     ;
ATD0DR5L:  equ $02DB     ;
ATD0DR6H:  equ $02DC     ;
ATD0DR6L:  equ $02DD     ;
ATD0DR7H:  equ $02DE     ;
ATD0DR7L:  equ $02DF     ;





;********** XGATE Map Registers *******************************

XGMCTL:    equ $0380     ; Module Control
XGCHID:    equ $0382     ; Channel Id
XGVBR_E:   equ $0385     ; Vector Base Addr [19:16]
XGVBR:     equ $0386     ; Vector Base Addr [15:1]
;XGVBR_L:   equ $0387     ; Vector Base Addr [7:1]
XGIF:      equ $0388     ; XG Int Flag base addr
XGIF7U:    equ $0388     ; Int Flag [78]
XGIF7L:    equ $0389     ; Int flag [77:70]
XGIF6U:    equ $038A     ; Int Flag [6F:68]
XGIF6L:    equ $038B     ; Int Flag [67:60]
XGIF5U:    equ $038C     ; Int Flag [5F:58]
XGIF5L:    equ $038D     ; Int Flag [57:50]
XGIF4U:    equ $038E     ; Int Flag [4F:48]
XGIF4L:    equ $038F     ; Int Flag [47:40]
XGIF3U:    equ $0390     ; Int Flag [3F:38]
XGIF3L:    equ $0391     ; Int Flag [37:30]
XGIF2U:    equ $0392     ; Int Flag [2F:28]
XGIF2L:    equ $0393     ; Int Flag [27:20]
XGIF1U:    equ $0394     ; Int Flag [1F:18]
XGIF1L:    equ $0395     ; Int Flag [17:10]
XGIF0U:    equ $0396     ; Int Flag [0F:09]
XGSWT:     equ $0398     ; SW Trigger - 2 bytes
;XGSWTH:    equ $0398     ; SW Trigger High
;XGSWTL:    equ $0399     ; SW Trigger Low
XGSEM:     equ $039A     ; Semaphore - 2 bytes
;XGSEMH:    equ $039A     ; Semaphore High
;XGSEML:    equ $039B     ; Semaphore Low
XGCCR:     equ $039D     ; Condition Code
XGPC:      equ $039E     ; PC - 2 bytes
;XGPCH:     equ $039E     ; PC High
;XGPCL:     equ $039F     ; PC Low
XGR1:       equ $03A2     ; Register 1
;XGR1H:       equ $03A2     ; Register 1 High
;XGR1L:       equ $03A3     ; Register 1 Low
XGR2:       equ $03A4     ; Register 2
;XGR2H:       equ $03A4     ; Register 2 High
;XGR2L:       equ $03A5     ; Register 2 Low
XGR3:       equ $03A6     ; Register 3
;XGR3H:       equ $03A6     ; Register 3 High
;XGR3L:       equ $03A7     ; Register 3 Low
XGR4:       equ $03A8     ; Register 4
;XGR4H:       equ $03A8     ; Register 4 High
;XGR4L:       equ $03A9     ; Register 4 Low
XGR5:       equ $03AA     ; Register 5
;XGR5H:       equ $03AA     ; Register 5 High
;XGR5L:       equ $03AB     ; Register 5 Low
XGR6:       equ $03AC     ; Register 6
;XGR6H:       equ $03AC     ; Register 6 High
;XGR6L:       equ $03AD     ; Register 6 Low
XGR7:       equ $03AE     ; Register 7
;XGR7H:       equ $03AE     ; Register 7 High
;XGR7L:       equ $03AF     ; Register 7 Low









