;
; =================================================
;
;   J1_350.asm		9S12XDT512 Test File
;
;   Version:		1.0   02/12/05
;   Author:		      Gary Karnes
;   Compiler:		AS12
;
;   Platform:		DEMO9S12XDT512
;   Purpose:		Check I/O pins on J1
; =================================================
;
; This test requires a loop back board on J1
; The loop board should have the following
;   PA0  - PA7   Odd shorted to even bits 39,37,35,33,31,29,27,25      
;   PAD0 - PAD7  Odd shorted to even bits 24,22,20,18,16,14,12,10      
;   PJ6  - PJ7   shorted     26,28   
;   PP0  - PP5   Odd shorted to even bits  9,11,30,32,34,36 
;   PP7  - PAD7  shorted     8,10  
;   PS2  - PS3   shorted     38,40
;   PT0  - PT1   shorted     13,15


J1_350:


; Setup Ports 

         movb   #$55,DDRA     ; Setup port A

         movb   #$FF,ATD0DIEN   ; PDA0 - PDA7 enble port
         movb   #$55,DDR1AD0    ; odd bits as outputs


         bset   DDRM,$0C      ; PM2 & PM4 as output
         bclr   DDRM,$30      ; PM3 & PM5 as input

         bset   DDRP,$15      ; Port P bits 0,2,4 as outputs
         bclr   DDRP,$AA      ; Port P bits 1,3,4 as inputs

         bset   DDRS,$08      ; Port S bit 3 as output (tx)  

         bset   DDRT,$01      ; PT0 as output
         bclr   DDRT,$02      ; PT1 as input

         jsr   M_CRLF
         jsr   M_CRLF
         jsr   String2
         fdb   MJ1           ; J1
         fdb   MTest         ; Test
         jsr   M_CRLF

         jsr   String3
         fdb   MDisable      ; Disable USER Jumpers
         fdb   MUSER         ;
         fdb   MJumpers      ;
         jsr   String3
         fdb   M11           ; 11 & 12
         fdb   Mand          ; 
         fdb   M12           ;

         jsr   PKEY          ; Press a key    

         jsr   M_CRLF
         jsr   M_CRLF
         jsr   String3
         fdb   MInstall      ; Install Test Board
         fdb   MTest         ; 
         fdb   MBoard        ;
         jsr   PKEY          ; Press a key
         jsr   M_CRLF

;=========================================================
; Test Port A

         clr    PORTA              ; clear odd bits
         idiv                      ; delay
         brclr  PORTA,$AA,J1_A_Nt1
         lbra   J1_A_F             ; Report Failed


J1_A_Nt1:

         bset   PORTA,$55          ; set odd bits high  
         idiv                      ; delay
         brset  PORTA,$AA,J1_A_Nt2

J1_A_F:

         jsr    M_CRLF             ; new line
         jsr    String2
         fdb    MPort              ; Port A
         fdb    MA    
         jsr    M_CRLF             ; new line
         lbra   Failed             ; Report Failed

J1_A_Nt2:
;
;==========================================================
; Port PAD00 - PAD07

         clr    PT1AD0             ; clear odd bits
         idiv                      ; delay
         brclr  PT1AD0,$AA,J1_AD_Nt1
         lbra   J1_AD_F             ; Report Failed


J1_AD_Nt1:

         bset   PT1AD0,$55          ; set odd bits high  
         idiv                      ; delay
         brset  PT1AD0,$AA,J1_AD_Nt2

J1_AD_F:

         jsr    M_CRLF             ; new line
         jsr    String2
         fdb    MPort              ; Port AD
         fdb    MAD    
         jsr    M_CRLF             ; new line
         lbra   Failed             ; Report Failed

J1_AD_Nt2:
 
     


;
;=============================================================
; Test Port M

         bclr   PTM,$0C           ; Set PM2 & PM4 low
         idiv                     ; delay
         brclr  PTM,$30,J1_M_Nt1
         lbra   J1_M_F            ; Report Failed

J1_M_Nt1:

         bset   PTM,$0C           ; set PM2 & PM4 high  
         idiv                     ; delay
         brset  PTM,$30,J1_M_Nt2  ;
         
J1_M_F:

         jsr    M_CRLF            ; new line
         jsr    String2
         fdb    MPort             ; Port M
         fdb    MM    
         jsr    M_CRLF            ; new line
         lbra   Failed            ; Report Failed

J1_M_Nt2:

;
;=============================================================
; Test Port P

         bclr   PTP,$15           ; clear odd bits
         idiv                     ; delay
         brclr  PTP,$2A,J1_P_Nt1
         lbra   J1_P_F            ; Report Failed

; check PP7, connected to PAD07
         clr    PT1AD0             ; clear odd bits
         idiv                      ; delay
         brclr  PTP,$80,J1_P_Nt1
         lbra   J1_P_F             ; Report Failed




J1_P_Nt1:

         bset   PTP,$15            ; set odd bits high  
         idiv                      ; delay
         brset  PTP,$2A,J1_P_Nt2   ;
         bra    J1_P_F             ; report failed
 
J1_P_Nt2:


; Check PP7, connected to PAD07

         bset   PT1AD0,$80
         idiv
         brset  PTP,$80,J1_P_Nt3  ; 
         
J1_P_F:

         jsr    M_CRLF            ; new line
         jsr    String2
         fdb    MPort             ; Port P
         fdb    MP    
         jsr    M_CRLF            ; new line
         lbra   Failed            ; Report Failed

J1_P_Nt3:

;
         
  
;==============================================================

; Test Port S bits 2 & 3

          bset    DDRE,$04           ; PE2 as output
          bclr    PORTE,$04          ; Disable LIN Driver

          
          bclr   PTS,$08            ; set bit 3 low  
          idiv                       ; delay

          brclr  PTS,$04,J1_S_Nt1
          lbra   J1_S_F              ; Report Failed

J1_S_Nt1:

          bset   PTS,$08           ; set bit 3 high  
          idiv                       ; delay
          brset  PTS,$04,J1_S_Nt2

J1_S_F:

         jsr    M_CRLF               ; new line
         jsr    String2
         fdb    MPort                ; Port S
         fdb    MS    
         jsr    M_CRLF               ; new line
         lbra   Failed               ; Report Failed

J1_S_Nt2:

;============================================================
;
;=========================================================
; Test Port T

           bclr    PTT,$01           ; Set PT0 low
           idiv                      ; delay
           brclr   PTT,$02,J1_T_Nt1
           lbra    J1_T_F            ; Report Failed


J1_T_Nt1:


           bset    PTT,$01           ; set PT0 high
           idiv                      ; delay
           brset   PTT,$02,J1_Nt6    ; skip to next test

J1_T_F:

         jsr     M_CRLF
         jsr     String2
         fdb     MPort            ; Port T
         fdb     MT
         jsr     M_CRLF

         lbra    Failed           ; report Failed

J1_Nt6:

;================================================================
; Reinstall Jumpers 11 & 12 on USER        
         jsr   M_CRLF
         jsr   M_CRLF

         jsr   String3
         fdb   MInstall      ; Install USER Jumpers
         fdb   MUSER         ;
         fdb   MJumpers      ;
         jsr   String3
         fdb   M11           ; 11 & 12
         fdb   Mand          ; 
         fdb   M12           ;

         jsr   PKEY          ; Press a key    
         jsr   M_CRLF




         lbra    Passed           ;








